#
# spec file for package ruby-build
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# SLE does not provide "bats", which is required for testing.
%if %{undefined sle_version}
%bcond_without test
%else
%bcond_with test
%endif

Name:           ruby-build
Version:        20250529.1
Release:        1.1
BuildArch:      noarch
License:        MIT
Group:          Development/Languages/Ruby
URL:            https://github.com/rbenv/ruby-build
Summary:        Compile and install Ruby
Source0:        https://github.com/rbenv/ruby-build/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
%if %{with test}
BuildRequires:  bats
%endif
Requires:       bash
Requires:       curl
Requires:       gzip
Requires:       make
Requires:       tar
# Maybe Requires would be better.
Recommends:     %{name}-dependencies-mri

%description
ruby-build provides a simple way to compile and install different versions of Ruby on UNIX-like systems.

%package dependencies-mri
Summary:        Meta package for dependencies to build MRI
Requires:       automake
Requires:       bison
Requires:       gcc
Requires:       gdbm-devel
Requires:       gperf
Requires:       graphviz
Requires:       libffi-devel
Requires:       libjpeg-devel
Requires:       libyaml-devel
Requires:       openssl-devel
Requires:       readline-devel
Requires:       tk-devel

%description dependencies-mri
Meta package for ruby-build dependencies to build MRI.

%package dependencies-jruby
Summary:        Meta package for dependencies to build JRuby
Requires:       gcc-c++

%description dependencies-jruby
Meta package for ruby-build dependencies to build JRuby.

%package dependencies-truffleruby
Summary:        Meta package for dependencies to build TruffleRuby
Requires:       gcc
Requires:       openssl-devel

%description dependencies-truffleruby
Meta package for ruby-build dependencies to build TruffleRuby.

%package dependencies-mruby
Summary:        Meta package for dependencies to build mruby
Requires:       gcc
Requires:       git

%description dependencies-mruby
Meta package for ruby-build dependencies to build mruby.

%package dependencies-picoruby
Summary:        Meta package for dependencies to build PicoRuby
Requires:       gcc
Requires:       git

%description dependencies-picoruby
Meta package for ruby-build dependencies to build PicoRuby.

%prep
%autosetup -p1

%build

%install
PREFIX="%{buildroot}%{_prefix}" ./install.sh

sed -i 's|#!/usr/bin/env bash|#!/bin/bash|g' %{buildroot}%{_bindir}/*

%fdupes %{buildroot}%{_datadir}/ruby-build

%check
%if %{with test}
bats test
%endif

%files
%license LICENSE
%doc README.md
%{_bindir}/*
%dir %{_datadir}/ruby-build
%{_datadir}/ruby-build/*
%{_mandir}/man1/ruby-build*

%files dependencies-mri

%files dependencies-jruby

%files dependencies-truffleruby

%files dependencies-mruby

%files dependencies-picoruby

%changelog
* Thu May 29 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 20250529.1.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20250529.1
  * Mark Ruby 3.1 as EOL by @CamJN in #2536
  * Document examples of using custom defs by @jasonkarns in #2537
  * Cleanups for truffleruby-dev and truffleruby+graalvm-dev by @eregon in #2538
* Sat May 17 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 20250516.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20250516
  * Modify `update-jruby` script to require Java 21+ for JRuby 10+ by @mislav in #2531
  * Add 3.4.4 in 87f57bb7a8176afa7f9256a1bd6fa18d251f210e
* Wed May  7 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 20250507.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20250507
  * Add JRuby 10.0.0.1 and 9.4.12.1 by @headius in #2530
* Thu May  1 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 20250430.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20250430
  * Add mruby 3.4.0 by @hasumikin in #2527
  * Add TruffleRuby and TruffleRuby GraalVM 24.2.1 by @eregon in #2528
* Thu Apr 24 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 20250424.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20250424
  * Honor `$JAVA_HOME` in `require_java` by @ntkme in #2523
  * Update truffleruby-dev to use newer ubuntu download by @rwstauner in #2524
  * Update jruby-dev to use newer ubuntu download by @eregon in #2525
* Sat Apr 19 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 20250418.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20250418
  * Add 3.5.0-preview1 by @hsbt in #2522
* Tue Apr 15 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 20250415.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20250415
  * Add JRuby 10.0.0.0 by @headius in #2520
  * Add 3.4.3
* Wed Apr  9 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 20250409.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20250409
  * Added 3.3.8
  * Don't delete jruby.sh by @headius in #2517
* Wed Mar 26 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 20250326.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20250326
  * Added 3.1.7
  * Added 3.2.8
* Tue Mar 18 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 20250318.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20250318
  * Add TruffleRuby and TruffleRuby GraalVM 24.2.0 by @eregon in #2512
* Sat Feb 15 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 20250215.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20250215
  * Added 3.4.2
* Wed Feb 12 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 20250212.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20250212
  * Update JRuby to 9.4.12.0 by @headius in #2509
* Wed Feb  5 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 20250205.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20250205
  * Added 3.2.7
* Thu Jan 30 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 20250130.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20250130
  * Add JRuby 9.4.11.0 by @headius in #2506
* Mon Jan 27 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 20250127.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20250127
  * Allow "nonexistent version" test to work without brew by @piperswe in #2432
  * rbenv install: fix substituting $HOME with "~" by @mislav in #2501
  * compute_sha2: drop support for OS X Leopard by @mislav in #2502
  * Add TruffleRuby and TruffleRuby GraalVM 24.1.2 by @eregon in #2505
- Remove fix-test-requiring-git-repository.patch.
- Use %%fdupes on the installed files.
* Tue Jan 21 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 20250121.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20250121
  * Simplify logic for rpath, the comma syntax is supported by all compilers by @eregon in #2497
  * Improve test output for failed stubs by @mislav in #2498
  * Add JRuby 9.4.10.0 by @headius in #2500
* Sun Jan 19 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 20250115.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20250115
  * Added 3.3.7
- Changes from version 20250114:
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20250114
  * Fix library lookup path in vendored OpenSSL on Linux by @mislav in #2493 #2496
  * `script/update-cruby`: improve curl HTTP error handling by @kou029w in #2483
* Thu Dec 26 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20241225.2.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20241225.2
  * Fixed 3.4.1 checksum by @hsbt in #2481
  * Added 3.4-dev and 3.5-dev by @hsbt in #2482
- Changes from version 20241225.1:
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20241225.1
  * Added Ruby 3.4.1
- Changes from version 20241225:
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20241225
  * Removed unofficial releases by @hsbt in #2479
  * Add Ruby 3.4.0 by @hsbt in #2480
* Sat Dec 14 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20241213.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20241213
  * Added 3.4.0-rc1
  * Avoid array subscript error when checking OpenSSL versions by @mislav in #2461
  * Allow named pipes as build definition argument by @mislav in #2462
  * Clarify --list and --definitions in the README by @eregon in #2464
  * Suggest to install rubies in a user-writable directory in the README by @eregon in #2465
  * Add an environment variable to always build openssl/libssl by @eregon in #2466
  * Warn that Ruby 3.1 support ends in less than 6 months by @mislav in #2471
  * Update OpenSSL 3.0.15 by @hsbt in #2477
* Wed Nov  6 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20241105.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20241105
  * Add Ruby 3.3.6
  * Add JRuby 9.4.9.0 by @headius in #2460
* Wed Oct 30 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20241030.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20241030
  * Added 3.2.6
* Fri Oct 18 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20241017.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20241017
  * Use --enable-shared for dev builds too, not only for releases by @eregon in #2450
  * Fix linking to vendored OpenSSL on 64-bit systems by @mislav in #2452
  * Add TruffleRuby and TruffleRuby GraalVM 24.1.1 by @eregon in #2454
* Mon Oct  7 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20241007.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20241007
  * Add -d, --dir option to install to <prefix>/<definition> instead of <prefix> by @eregon in #2447
  * Support `ruby-build ruby-X.Y.Z DIR` by @eregon in #2448
  * Add Ruby 3.4.0-preview2 by @a-lavis in #2451
* Tue Sep 17 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20240917.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20240917
  * Bump up openssl-3.0.15 by @hsbt in #2440
  * Use GitHub instead of openssl.org by @hsbt in #2441
  * Add TruffleRuby and TruffleRuby GraalVM 24.1.0 by @eregon in #2446
* Fri Sep  6 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20240903.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20240903
  * Added 3.3.5
  * Clear LC_ALL for tr call by @headius in #2429
  * Auto update Ruby definition with Ruby releases by @hsbt in #2430
* Sat Jul 27 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20240727.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20240727
  * Add Ruby 3.2.5 by @sferik in #2428
* Wed Jul 24 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20240722.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20240722
  * Add TruffleRuby and TruffleRuby GraalVM 24.0.2 by @eregon in #2427
* Tue Jul  9 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20240709.1.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20240709.1
  * Use LTS version of OpenSSL 3 by @hsbt in #2422
- Update to version 20240709.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20240709
  * Add JRuby 9.4.8.0 by @headius in #2419
  * Add Ruby 3.3.4 by @yahonda in #2421
* Wed Jul  3 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20240702.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20240702
  * Add JRuby 9.3.15.0 by @headius in #2418
* Wed Jun 12 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20240612.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20240612
  * Clarify RUBY_BUILD_ROOT env var by @jasonkarns in #2392
  * Use LTS version of OpenSSL 3 by @hsbt in #2402
  * Update to openssl-3.0.14 by @hsbt in #2407
  * Simplify JRuby version check by @mislav in #2406
  * Fix package name for openssl-3.0.14 by @mislav in #2408
  * Add Ruby 3.3.3 by @k0kubun in #2409
* Thu May 30 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20240530.1.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20240530.1
  * Fix 3.1.6 version definition by @rafaelfranca in #2397
- Update to version 20240530.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20240530
  * Mark Ruby 3.0.7 as unsupported by @CamJN in #2386
  * Mark Ruby 3.0 as EOL by @mislav in #2388
  * Truncate teeny version from dev definitions by @hsbt in #2389
  * Add Ruby 3.3.2 by @k0kubun in #2396
  * Add CRuby release 3.1.6 by @sferik in #2395
* Fri May 17 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20240517.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20240517
  * Add Ruby 3.4.0-preview1 by @adam12 in #2384
* Wed May  1 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20240501.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20240501
  * Add JRuby 9.4.7.0 by @headius in #2375
  * Upgrade to OpenSSL 3.1.5 by @mislav in #2377
  * rbenv install: error out instead of prompting in non-interactive mode by @mislav in #2378
* Tue Apr 23 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20240423.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20240423
  * Add CRuby security-fix releases 3.0.7, 3.1.5, 3.2.4, and 3.3.1 by @kpfleming in #2370
* Tue Apr 16 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20240416.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20240416
  * Simplify `truffleruby+graalvm-dev` build definition re: download redirect by @mislav in #2361
  * Add TruffleRuby and TruffleRuby GraalVM 24.0.1 by @eregon in #2365
* Tue Mar 19 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20240319.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20240319
  * Add TruffleRuby and TruffleRuby GraalVM 24.0.0 by @eregon in #2359
* Mon Mar 18 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20240318.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20240318
  * Switch to EA builds from graalvm/graal-languages-ea-builds for truffleruby+graalvm-dev by @eregon in #2356
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Wed Feb 21 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20240221.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20240221
  * Add mruby-3.3.0 by @hasumikin in #2348
  * Add JRuby 9.3.14.0 and 9.4.6.0 by @headius in #2350
* Fri Jan 19 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20240119.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20240119
  * Add Ruby 3.2.3 by @TomNaessens in #2339
* Tue Jan 16 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 20240116.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20240116
  * Added 3.4-dev definition by @hsbt in #2329
  * Skip passing `--with-readline-dir` for Ruby 3.3+ by @mislav in #2333
  * Add TruffleRuby and TruffleRuby GraalVM 23.1.2 by @eregon in #2336
* Tue Dec 26 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20231225.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20231225
  * Use bats-core instead of archived version by @hsbt in #2325
  * Add Ruby 3.3.0 by @k0kubun in #2326
  * Switch 3.3.0-dev to ruby_3_3 branch by @hsbt in #2327
* Mon Dec 11 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20231211.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20231211
  * Add Ruby 3.3.0-rc1 by @casperisfine in #2323
  * Add `ruby-dev` definition by @eregon in #2311
  * Mark Ruby 3.0.x as unsupported by @mislav in #2307
  * Add script to update `warn_unsuppported`, `warn_eol` labels by @mislav in #2308
  * Remove deprecated `verify_openssl` step from build definitions by @mislav in #2314
  * Instruct Ruby to fail the build if openssl or psych are missing by @mislav in #2296
  * Fix compiling Ruby < 2.5 by omitting `--with-ext` by @mislav in #2316
  * Introduce "with_bundled_gems" build step for dev rubies and unify "standard" by @mislav in #2318
  * Fix linking to older OpenSSL for Ruby < 2.7.7 by @mislav in #2322
* Wed Nov 15 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20231114.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20231114
  * Fix commands printed when TMPDIR is empty by @mislav in #2303
  * Add option flags to ruby-build man page by @mislav in #2302
  * Abandon using `--show-progress` for wget by @mislav in #2304
  * Added 3.3.0-preview3 by @andreimaxim in #2310
* Tue Nov  7 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20231107.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20231107
  * ruby-build now prints external commands as they are executed - @mislav in #2230
    Now there is more transparency to what ruby-build does: at the glance of the output, it should be clear that ruby-build is mostly just a wrapper around the curl → untar → `./configure` → `make` → `make install` combo. Furthermore, when an error arises, it should now be more apparent which build step failed, even before having to dive into the log file.
    Additionally, network downloaders such as `curl`, `wget`, and `git` are now connected directly to the terminal, allowing them to display progress information.
    In `ruby-build --verbose` mode, the output of all external commands is now connected to the same stdout/stderr as the ruby-build process, and a log file doesn't get created anymore.
    The "BUILD FAILED" output is now improved: it includes CPU architecture information and is cleaner, drawing attention to the location of the build log on disk. (Most often, the real cause of a build failure is only discoverable via the log.)
  * Automatically link to Homebrew OpenSSL by @mislav in #2275 #2292
    With this change, it is no longer necessary to set `RUBY_CONFIGURE_OPTS=--with-openssl-dir=...` after doing `brew install openssl@3`. An appropriate OpenSSL version installed with Homebrew will get used for configuring Ruby automatically, even if the formula is "keg-only".
  * Add JRuby 9.4.5.0 and 9.3.13.0 by @headius in #2289
  * Add `ruby-build(1)` man page by @mislav in #2297
  * Respect NO_COLOR and CLICOLOR_FORCE by @mislav in #2295
  * Remove support for Topaz and Maglev by @mislav in #2294
  * Unmark Ruby 2.7 as soon-to-be-EOL since it's already EOL by @mislav in #2286
* Wed Oct 25 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20231025.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20231025
  * Cleanup in truffleruby+graalvm installation by @mislav in #2272
  * Avoid compiling OpenSSL if the user supplied `--with-openssl-dir` on the command line by @mislav in #2274
  * Cleanup in OpenSSL compilation step by @mislav in #2270
  * Avoiding excessive cd when fetching git repos by @mislav in #2273
  * Remove implicit LDFLAGS, CPPFLAGS, and "ldflags_dirs" build step by @mislav in #2271
  * Add tests for functionality related to linking to OpenSSL by @mislav in #2276
  * Add JRuby 9.4.4.0 by @headius in #2277
  * Remove strict `openssl@1.1` requirement from TruffleRuby, jruby-dev definitions by @mislav in #2278
  * Fix fixing JRuby shebangs on macOS by @mislav in #2280
  * Skip ri/rdoc when installing jruby-launcher by @eregon in #2281
  * Bump up OpenSSL 3.1.4 by @hsbt in #2283
  * Add TruffleRuby and TruffleRuby GraalVM 23.1.1 by @eregon in #2284
* Sat Oct 14 2023 Lukas Müller <lukas@localhost>
- Update to version 20231014.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20231014
  * Add RUBY_BUILD_TARBALL_OVERRIDE to override the ruby tarball URL by @eregon in #2258
* Thu Oct 12 2023 Lukas Müller <lukas@localhost>
- Update to version 20231012.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20231012
  * Bump up OpenSSL 3.1.3 by @hsbt in #2257
  * Bump mislav/bump-homebrew-formula-action from 2 to 3 by @dependabot in #2259
  * Bump redhat-plumbers-in-action/differential-shellcheck from 4 to 5 by @dependabot in #2265
  * Set default MAKE=make on FreeBSD by @Freaky in #2263
  * Pass ruby configuration flags on the command line by @mislav in #2267
  * Enable shellcheck parsing of ruby-build source by @mislav in #2268
  * Use builds from ruby/truffleruby-dev-builder for truffleruby-dev on macos-arm64 by @eregon in #2269
* Tue Sep 19 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20230919.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230919
  * Add TruffleRuby and TruffleRuby GraalVM 23.1.0 by @eregon in #2254
* Thu Sep 14 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20230914.1.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230914.1
  * Use the TruffleRuby JVM Standalones for truffleruby+graalvm-dev by @eregon in #2251
  * Update URLs for truffleruby+graalvm-dev by @eregon in #2252
* Thu Sep 14 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20230914.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230914
  * workaround jruby#7799 by updating rubygems for JRuby 9.2.x by @jsvd in #2246
  * Added 3.3.0-preview2 by @hsbt in #2249
  * Bump up openssl-1.1.1w by @hsbt in #2250
* Mon Sep 11 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20230912.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230912
  * Bump actions/checkout from 3 to 4 by @dependabot in #2247
  * Add JRuby 9.3.11.0 by @headius in #2248
* Mon Sep  4 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20230904.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230904
  * Show openssl version used from homebrew by default by @MatasNed in #2226
  * Bump up OpenSSL versions by @hsbt in #2227
  * Avoid test failure when stubbing FreeBSD environment by @mislav in #2228
  * Display the actual error when testing for Ruby's openssl extension by @YellowApple in #2223
  * Remove `require_gcc` implementation by @mislav in #2232
  * Remove `require_llvm` implementation by @mislav in #2231
  * Update URLs for truffleruby+graalvm-dev by @eregon in #2244
* Mon Jul 17 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20230717.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230717
  * Follow truffleruby dev standalones rename by @eregon in #2219
* Mon Jul 10 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20230710.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230710
  * Bump up the latest versions of OpenSSL by @hsbt in #2216
* Thu Jun 15 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20230615.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230615
  * Print a message about the new distribution and license when installing TruffleRuby 23.0 by @eregon in #2209
* Wed Jun 14 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20230614.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230614
  * Add TruffleRuby and TruffleRuby+GraalVM 23.0.0 by @eregon in #2207
* Thu Jun  8 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20230608.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230608
  * Add JRuby 9.4.3.0 by @headius in #2203
* Fri May 12 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20230512.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230512
  * Added Ruby 3.3.0-preview1 by @hsbt in #2193
* Fri Apr 28 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20230428.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230428
  * Add TruffleRuby 23.0.0-preview1 by @eregon in #2190
  * Add TruffleRuby+GraalVM 23.0.0-preview1 by @eregon in #2191
* Mon Apr 24 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20230424.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230424
  * Fall back on shasum if sha256sum is unavailable by @jas14 in #2177
  * Mark EOL status to Ruby 2.6 and 2.7 by @hsbt in #2180
  * Fix uploading SARIF reports from Differential Shellcheck by @mislav in #2181
  * Fix compilation of Ruby 3.2.x on FreeBSD by @jarmo in #2187
  * Fix truffleruby+graalvm-dev download URLs by @eregon in #2189
* Thu Mar 30 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20230330.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230330
  * Add definitions for Ruby 2.7.8, 3.0.6, 3.1.4, 3.2.2 by @jas14 in #2174
  * Upgrade from OpenSSL 3.0 to OpenSSL 3.1 by @mislav in #2175
  * Avoid shellcheck CI job commenting on every PR by @mislav in #2176
  * Remove AWS access key ID from version control by @mislav in #2163
* Sat Mar 11 2023 Lukas Müller <expeehaa@outlook.com>
- Change summary and description of dependency packages to shut up rpmlint.
* Thu Mar  9 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20230309.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230309
  * Add JRuby 9.4.2.0 by @headius in #2160
* Tue Mar  7 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20230306.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230306
  * Add mruby-3.2.0 by @hasumikin in #2155
  * Automatically detect and link to Homebrew's libyaml by @dreyks in #1929
* Thu Feb 23 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20230222.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230222
  * release script: handle multiple releases on the same day by @mislav in #2148
  * Remove brew update instruction by @ohbarye in #2151
  * Update TruffleRuby dev release URLs by @nirvdrum in #2152
* Wed Feb  8 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20230208.1.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230208.1
  * Add Ruby 3.2.1 by @pmor in #2147
  * Remove obsolete `topaz-dev` formula by @hsbt in #2146
- Changes from version 20230208.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230208
  * Remove patch for openssl-1.1.1q by @eregon in #2139
  * Add JRuby 9.4.1.0 by @headius in #2138
  * Added dependabot update for GitHub Actions by @hsbt in #2141
  * Bump actions/checkout from 2 to 3 by @dependabot in #2142
  * Update old versions of JRuby URLs by @hsbt in #2145
  * Bump up latest stable versions of OpenSSL by @hsbt in #2140
  * Bump mislav/bump-homebrew-formula-action from 1 to 2 by @dependabot in #2143
  * Bump redhat-plumbers-in-action/differential-shellcheck from 3 to 4 by @dependabot in #2144
* Wed Feb  1 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20230202.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230202
  * Add JRuby 9.3.10.0 by @headius in #2137
* Tue Jan 24 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 20230124.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20230124
  * Development of 3.3.0 started by @hsbt in #2116
  * Warn EOL status for all of rbx packages by @hsbt in #2117
  * svn.ruby-lang.org is shutdown now. by @hsbt in #2120
  * Drop svn support by @hsbt in #2121
  * Add TruffleRuby and TruffleRuby GraalVM 22.3.1 by @eregon in #2134
* Sun Dec 25 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20221225.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20221225
  * Added 3.2.0 by @hsbt in https://github.com/rbenv/ruby-build/pull/2115
* Tue Dec  6 2022 Sam Hart <criswellious@gmail.com>
- Update to version 20221206.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20221206
  * Add definition for Ruby 3.2.0 RC 1 by @koic in #2110
- Update to version 20221124
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20221124
  * Add definition for Ruby 3.1.3, 3.0.5, and 2.7.7 by @koic in #2096
- Update to version 20221123
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20221123
  * JRuby 9.4.0.0 by @headius in #2095
* Mon Nov 21 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20221121.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20221121
  * truffleruby+graalvm-dev builds are now based on Java 17 by @eregon in #2093
* Fri Nov 18 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20221116.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20221116
  * Add definition for Ruby 3.2.0-preview3 by @koic in #2087
  * Update to OpenSSL 1.1.1s by @mislav in #2088
  * Do not automatically enable YJIT nor attempt to detect rustc, as Ruby 3.2 now does that automatically by @mislav in #2091
  * Mark Ruby 2.6 as EOL and 2.7 as "unsupported" by @mislav in #2077
* Thu Nov  3 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20221101.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20221101
  * Use OpenSSL 3.0.7 for ruby 3.1 by @richardTowers in #2075
* Wed Oct 26 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20221026.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20221026
  * Add TruffleRuby and TruffleRuby GraalVM 22.3.0 by @eregon in #2070
* Mon Oct 24 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20221025.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20221025
  * Add JRuby 9.3.9.0 by @headius in #2068
* Tue Oct  4 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20221004.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20221004
  * Fix rbenv install --list exit status by @mislav in #2059
* Fri Sep 30 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20220930.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20220930
  * Add JRuby 9.3.8.0 by @headius in #2045
  * Use GMP from Homebrew if available by @casperisfine in #2044
  * Fix linking to system OpenSSL on OpenSUSE by @hsbt in #2049
  * rbenv-install: suggest rbenv global if there is no explicit global setting by @mislav in #2052
  * rbenv-install: only print stderr notice if printing list output to a terminal by @mislav in #2055
  * Touch up README for comprehension and clarity by @mislav in #2051
  * Add minimum GitHub token permissions for workflows by @varunsh-coder in #2041
  * Add Differential ShellCheck as shell linter by @jamacku in #2042
  * Release with gh instead of with hub by @mislav in #2056
* Mon Sep 12 2022 Lukas Müller <expeehaa@outlook.com>
- Add dependency packages for more Ruby interpreters.
* Sun Sep 11 2022 Lukas Müller <expeehaa@outlook.com>
- Split dependencies for building different Ruby versions in dedicated packages.
* Sat Sep 10 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20220910.1.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20220910.1
  * enable YJIT with 3.2.0-preview2
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20220910
  * Fixed regex pattern for YJIT
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20220909
  * YJIT support arm64 and aarch64 arch
  * Added 3.2.0-preview2
- Add dependency on libyaml-devel for building Ruby 3.2.0+.
- Add missing dependencies on tar and make.
* Thu Aug 25 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20220825.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20220825
  * Show the log file to make it easy to follow progress
  * Fixes #1721
  * Add JRuby 9.3.7.0 (#2026)
* Tue Jul 26 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20220726.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20220726
  * Add TruffleRuby 22.2.0
- Update to version 20220725.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20220725
  * Only check the opensslv.h header to find the system openssl version
  * openssl version can be another version than the header, for instance with
  * apt-get install --no-install-recommends ca-certificates libssl1.0-dev on Ubuntu 18.04: #2014 (reply in thread)
* Thu Jul 21 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20220721.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20220721
  * For Ruby 3.2.0-dev, install YJIT by default if rustc 1.60+ is available
  * Don't auto-enable YJIT except on x86_64
  * Restructure build_package_enable_yjit to be cleaner and to exit before later checks if possible.
  * Apply patch for implicitly declaration error of OpenSSL 1.1.1q
  * Use inline patch instead of curl download
* Thu Jul 14 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20220713.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20220713
  * Use OpenSSL 3.x with Ruby 3.1.x
* Sun Jul 10 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20220710.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20220710
  * Use OpenSSL 3.0.5
  * Use OpenSSL 1.1.1q
  * Install openssl 1 when openssl is 3
  * Install openssl whenever the system version does not match
  * Make supported openssl versions explicit per definition.
* Thu Jun 30 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20220630.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20220630
  * Add JRuby 9.2.21.0 and 9.3.6.0
  * Add mruby-3.1.0
  * Add picoruby-3.0.0
* Sat Jun 11 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20220610.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20220610
  * Skip building docs when building openssl
  * See openssl/openssl#8170
  * The install_sw target exists since 1.0.0 or earlier:
    https://github.com/openssl/openssl/blob/OpenSSL_1_0_0-stable/Makefile.org
  * Re-enable ssldir creation target for openssl install
    Prior commit attempts to shorten install by omitting documentation install,
    however an additional target is needed to get the conf dirs for capturing the
    PEMs et al.
  * OpenSSL 1.1+ needs the extra install_ssldirs target to install certificates
  * Add Darwin-arm64 and Linux-aarch64 for truffleruby-dev and truffleruby+graalvm-dev
* Tue May 24 2022 Lukas Müller <expeehaa@outlook.com>
- Run "osc service runall format_spec_file".
* Tue Apr 26 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20220426.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20220426
  * Add TruffleRuby and TruffleRuby GraalVM 22.1.0
* Fri Apr 15 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20220415.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20220415
  * Allow truffleruby to install in an existing empty directory
* Tue Apr 12 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20220412.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20220412
  * Add definition for Ruby 3.2.0-preview1
  * Add Ruby 3.1.2, 3.0.4, 2.7.6, 2.6.10
* Thu Mar 24 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20220324.
  Changelog: https://github.com/rbenv/ruby-build/releases/tag/v20220324
  * Bump up OpenSSL 1.1.1n and 3.0.2
  * Update openssl version at 2.4.0-preview versions
  * Add JRuby 9.3.4.0
* Fri Feb 18 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20220218.
- Changelog:
  https://github.com/rbenv/ruby-build/releases/tag/v20220218
  * Added Ruby 3.1.1
* Wed Jan 26 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 20220125.
- Changelog:
  https://github.com/rbenv/ruby-build/releases/tag/v20220125
  * Add JRuby 9.3.3.0
  * Add TruffleRuby and TruffleRuby GraalVM 22.0.0.2
* Sat Dec 25 2021 Lukas Müller <expeehaa@outlook.com>
- Update to version 20211225.
- Changelog:
  https://github.com/rbenv/ruby-build/releases/tag/v20211225
  * Add Ruby 3.1.0.
* Fri Dec  3 2021 Lukas Müller <expeehaa@outlook.com>
- Update to version 20211203.
- Changelog v20211203:
  https://github.com/rbenv/ruby-build/releases/tag/v20211203
  * Add JRuby 9.3.2.0
- Changelog v20211201:
  https://github.com/rbenv/ruby-build/releases/tag/v20211201
  * Add JRuby 9.2.20.1
* Wed Nov 24 2021 Lukas Müller <expeehaa@outlook.com>
- Update to version 20211124.
- Changelog:
  https://github.com/rbenv/ruby-build/releases/tag/v20211124
  * Add ruby 2.6.9, 2.7.5 and 3.0.3
* Wed Nov 10 2021 Lukas Müller <expeehaa@outlook.com>
- Update to version 20211109.
- Replace the source download service with a static source archive
  and a disabled service to update the sources manually.
* Sat Nov  6 2021 Lukas Müller <expeehaa@outlook.com>
- Update to v20211019.
- Changelog:
  https://github.com/rbenv/ruby-build/releases/tag/v20211019
- Enable testing.
* Tue Apr 27 2021 Andrey Gankov <gav@qsolution.ru>
- Update to v20210423: changelog at:
  https://github.com/rbenv/ruby-build/releases/tag/v20210423
* Sun Oct  4 2020 Michele Bologna <Michele.Bologna@suse.com>
- Update to v2020926 from v20200727. Changelog at:
  https://github.com/rbenv/ruby-build/releases/tag/v20200926
* Wed Jul 29 2020 Michele Bologna <Michele.Bologna@suse.com>
- Update to v20200727 from v20200401. Changelog at:
  https://github.com/rbenv/ruby-build/releases/tag/v20200727
* Thu May  7 2020 Ana María Martínez Gómez <anamaria@martinezgomez.name>
- Update to v20200401 from v20190401. Changelog at:
  https://github.com/rbenv/ruby-build/releases?after=v20200402
* Tue Jan 29 2019 dmacvicar@suse.de
- Update to v20181225: changelog at:
  https://github.com/rbenv/ruby-build/releases/tag/v20181225
* Sun Aug 26 2018 timo.goellner@googlemail.com
- Update to v20180822: changelog at:
  https://github.com/rbenv/ruby-build/releases/tag/v20180822
* Tue Mar 27 2018 michele.bologna@suse.com
- Update to v20180224: changelog at:
  https://github.com/rbenv/ruby-build/releases/tag/v20180224
* Wed Feb 14 2018 michele.bologna@suse.com
- Update to v20171215: changelog at:
  https://github.com/rbenv/ruby-build/releases/tag/v20171226
* Mon Jul 24 2017 kpimenov@suse.com
- update to v20170523
- https://github.com/rbenv/ruby-build/releases/tag/v20170523
* Wed Mar 15 2017 mamorales@suse.com
- update to v20170201
- https://github.com/rbenv/ruby-build/releases/tag/v20170201
* Wed Jan 25 2017 kpimenov@novell.com
- update to v20170112
- https://github.com/rbenv/ruby-build/releases/tag/v20170112
* Mon Dec 19 2016 kpimenov@novell.com
- update to v20161121
- https://github.com/rbenv/ruby-build/releases/tag/v20161121
* Mon Jun 20 2016 dmacvicar@suse.de
- update to v20160602
- https://github.com/rbenv/ruby-build/releases/tag/v20160602
* Wed Dec 30 2015 dmacvicar@suse.de
- update to v20151226
- https://github.com/rbenv/ruby-build/releases/tag/v20151226
* Wed Mar 18 2015 dmacvicar@suse.de
- add libffi-devel as MRI 2.2.1 does not build with the
  bundled one
* Wed Mar 18 2015 dmacvicar@suse.de
- update to v20150303
* Wed Jan 21 2015 dmacvicar@suse.de
- update to v20150116
* Wed Nov 12 2014 dmacvicar@suse.de
- update to v20141028
* Fri Jan 31 2014 dmacvicar@suse.de
- update to v20140110.1
* Wed Jan  8 2014 dmacvicar@suse.de
- update to v20131220
* Fri Oct 18 2013 dmacvicar@suse.de
- update to v20131008
* Sun Feb 24 2013 dmacvicar@suse.de
- update to v20130224
* Wed Dec 12 2012 dmacvicar@suse.de
- update to v20121204
* Fri May 25 2012 dmacvicar@suse.de
- update to v20120524
* Sun Mar 18 2012 dmacvicar@suse.de
- update to v20120216
* Thu Jan 19 2012 dmacvicar@suse.de
- update to v20111230
- add Url tag
* Wed Jan  4 2012 dmacvicar@suse.de
- add curl to Requires
- add ruby MRI BuildRequires to Requires
* Wed Jan  4 2012 dmacvicar@suse.de
- add BuildRoot tag
* Wed Nov 16 2011 dmacvicar@suse.de
- initial package for v20111030
